# Disclaimer - This shit ain't done
# Coolered
## A better [dslackw/colored](https://github.com/dslackw/colored)
I read the readme of dslackw/colored for Python, and thought it was too complicated. This will be an interface so simple you memorize it immediately.

## Example
```
# Colors
color('red', 'This is red')
color('blue', 'This is blue')
color('yellow', 'This is yellow')

# Backgrounds
color('red', "This is red with a blue background", bg='blue')
color('blue', "This is blue with a yellow background", bg='yellow')


# That's it
```

## Color reference chart

## Installation
```
pip install coolered
```
## Uninstallation
```
pip uninstall coolered
```
